==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/sv.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Laddar förhandsvisning...",
    "Saved" : "Sparat",
    "Admin" : "Admin",
    "a safe home for all your data" : "En säker plats för alla dina filer och data",
    "The given name is too long" : "Det angivna namnet är för långt",
    "The given web address is too long" : "Den angivna adressen är för lång",
    "The given slogan is too long" : "Den angivna slogan är för lång",
    "The given color is invalid" : "Den angivna färgen är inte tillgänglig",
    "No file uploaded" : "Ingen fil uppladdad",
    "Unsupported image type" : "Filtypen är ej giltig",
    "You are already using a custom theme" : "Du använder redan ett annat tema",
    "Theming" : "Teman",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Teman gör det möjligt att enkelt skräddarsy utseendet på ditt moln. Detta kommer att synas för alla användare.",
    "Name" : "Namn",
    "Web address" : "Webbadress",
    "Web address https://…" : "Webbadress https://...",
    "Slogan" : "Slogan",
    "Color" : "Färg",
    "Logo" : "Logotyp",
    "Upload new logo" : "Ladda upp ny logotyp",
    "Login image" : "Inloggningsbild",
    "Upload new login background" : "Ladda upp ny bakgrundsbild",
    "Remove background image" : "Ta bort bakgrundsbild",
    "reset to default" : "Återställ till standard",
    "Log in image" : "Inloggningsbild"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/sv.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Laddar förhandsvisning...",
    "Saved" : "Sparat",
    "Admin" : "Admin",
    "a safe home for all your data" : "En säker lagringsplats för all din data",
    "The given name is too long" : "Det angivna namnet är för långt",
    "The given web address is too long" : "Den angivna adressen är för lång",
    "The given slogan is too long" : "Den angivna slogan är för lång",
    "The given color is invalid" : "Den angivna färgen är inte tillgänglig",
    "No file uploaded" : "Ingen fil uppladdad",
    "Unsupported image type" : "Filtypen är ej giltig",
    "You are already using a custom theme" : "Du använder redan ett annat tema",
    "Theming" : "Teman",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Teman gör det möjligt att enkelt skräddarsy utseendet på ditt moln. Detta kommer att synas för alla användare.",
    "Name" : "Namn",
    "Reset to default" : "Återställ till grundinställningar",
    "Web address" : "Webbadress",
    "Web address https://…" : "Webbadress https://...",
    "Slogan" : "Slogan",
    "Color" : "Färg",
    "Logo" : "Logotyp",
    "Upload new logo" : "Ladda upp ny logotyp",
    "Login image" : "Inloggningsbild",
    "Upload new login background" : "Ladda upp ny bakgrundsbild",
    "Remove background image" : "Ta bort bakgrundsbild",
    "reset to default" : "Återställ till standard",
    "Log in image" : "Inloggningsbild"
},
"nplurals=2; plural=(n != 1);");
